*******
Magnopy
*******

Magnopy is a Python package for the magnon-related properties:

* Dispersion
* Relaxation
* Critical temperature
* Correlations

Please visit an extensive documentation on `magnopy.org <https://magnopy.org>`_ to find out more.

Installation
============

To install magnopy run (you may need to use ``pip3``):

.. code-block:: console

  pip install magnopy
